@@ -12,7 +12,7 @@ async def client(queue_client: redis.Redis, workers_required: int):
         Client for Workers, Tasks & AsyncIO's Event Loop
     """
     queue = create_worker_queue()
-
+    await asyncio.sleep(1)  # TODO this is a quick fix
     next_task = await get_task_from_queue_client(queue_client)
     uow_metadata = await deserialize_task(next_task[1])
     serialized_uow = await deserialize_task(uow_metadata["serialized_uow"])
@@ -28,7 +28,7 @@ async def client(queue_client: redis.Redis, workers_required: int):
 
     # Create `3` workers tasks to process the queue concurrently
     tasks = []
-    for i in range(workers_required):  # TODO update amount of workers with user options
+    for i in range(workers_required):
         task = asyncio.create_task(worker(queue, queue_client))
         tasks.append(task)
     # Wait until queue is fully processed
